******************************************************************************
******************************************************************************
* Sample description (Family paper)
*
* Author: LT, LF, VK
* Created: 09/03/2021
* Updated:
******************************************************************************
******************************************************************************

version 16
set more off 
set trace off

do $path\HOPPprepared\do\globals

gl results  $path\HOPPprepared\results\family_paper\version2

*--------------------------------------------------------------------------
********* Sample description **** PAPER VERSION 2 *************************
*--------------------------------------------------------------------------


use  $data\analysis_fam_panel_weights_KIDS_NEW.dta, clear
drop if par_2 ==1		



graph set window fontface "Times New Roman
*** Clone time variable and DV
clonevar time = covidtime
clonevar hours = workhours


*For other vars:  	
*Define globals
gl outcomes "hours KUG_Anteil"

gl covars_general "female age agesq mig educ_isced_1to3 educ_isced_4to5 educ_isced_6"
gl covars_fam "dummykid partner_w1"
gl covars_cc "access_ft1 access_ft2 access_ft3 "
gl covars_work "ho_b employ_yearscontri_ausbi employ_years3 alo" 

gl times "0 1 2 3 4"


*Open postfile
postutil clear
postfile descriptives_FAM_uw str50 varname time N_obs average stdev minimum maximum using "$results\descriptives_FAM_uw.dta", replace


*Calculate means - time varying
foreach var in $outcomes {

		foreach t in $times {
		
		*Define locals
		local varlabel: variable label `var'
		
		*Calculation of descriptives via "sum"
		sum `var' if time == `t'
		
		*Store results 
		scalar N_obs     = `r(N)'
		scalar average   = `r(mean)'
		scalar stdev     = `r(sd)'
		scalar minimum   = `r(min)'
		scalar maximum   = `r(max)'
	
		
		*Post results
		post descriptives_FAM_uw ("`varlabel'") (`t') (N_obs) (average) (stdev) (minimum) (maximum)
		
	   }
	}

	
*Calculate means - time invariant
foreach var in $covars_general $covars_fam $covars_cc  $covars_work {

		
		
		*Define locals
		local varlabel: variable label `var'
		
		*Calculation of descriptives via "sum"
		sum `var' if time == 0
		
		*Store results 
		scalar N_obs     = `r(N)'
		scalar average   = `r(mean)'
		scalar stdev     = `r(sd)'
		scalar minimum   = `r(min)'
		scalar maximum   = `r(max)'
	
		
		*Post results
		post descriptives_FAM_uw ("`varlabel'") (0) (N_obs) (average) (stdev) (minimum) (maximum)
		
	}
		
	
postclose descriptives_FAM_uw


*Load generated dataset
use "$results\descriptives_FAM_uw.dta", clear

*Produce descriptives table
putdocx clear
putdocx begin

gl title "Descriptives - unweighted"
gl notes "Note: For all dummy variables, means indicate shares" 

putdocx table descriptives_FAM_uw = data(varname t N_obs average stdev minimum maximum), ///
	varnames title("$title") note("$notes")

putdocx save "$results\descriptives_FAM_uw.docx", replace




