*******************************************************************************

*** Produce MARGIN-PLOTS

*** Authors: LF & LT
********************************************************************************

set more off
set trace off
capture log close

do $path\HOPPprepared\do\globals
 

do $path\HOPPprepared\do\globals
gl results  $path\HOPPprepared\results\family_paper\version2
gl graph $path\HOPPprepared\graph\family_paper\version2

************************* MARGINS FOR V 2  WEIGHTED

use  $data\analysis_fam_panel_weights_KIDS_NEW.dta, clear
drop if par_2 ==1		



graph set window fontface "Times New Roman"


gl bs "i.female##i.dummykid" //basic specification
gl cc "i.female##i.access_ftcc" //childcare specification

gl general "age agesq educ_isced_4to5 educ_isced_6 mig"
gl fam "partner_w1"
gl work "ho_b KUG_Anteil"
gl emphist "employ_yearscontri_ausbi employ_years3 alo"

gl start "wh_b"
gl weight cweight_rlc



*********************************************************************
**Interactions between female and dummykid for different timepoints**
*********************************************************************

global sub	  "covidtime"
la var female "being female" 
la var dummykid "having child(ren) under 15"


***BASIC SPECIFICATION:
*-----------------------
  forvalues x = 1/4 {
    
	foreach treat in female {
	    
		foreach interact in dummykid {
		
		**************
		*Define locals
		**************
		
		*Variable labels (treatment and interaction variable)
		local label_treat: 		variable label `treat'
		local interact_treat:	variable label `interact'
		
		*Value labels (sub-group variable)
		local groupvallabel: value label $sub 
		local vallabel`x': label `groupvallabel' `x'
		
		*Value labels (interaction variable)
		local interact_vallabel: value label `interact' 
		levelsof `interact', local(levels)
			foreach l of local levels {
			local interact_vallabel`l': label `interact_vallabel' `l'
			di as text "`interact_vallabel`l''"
			}
		
		***********
		*Regression
		************
		log using "$log/margins_bs`x'.log", replace
		
		reg diff`x' i.female##i.dummykid $general $fam $work $emphist [aweight=$weight], robust
		
		******************
		*Calculate margins
		*******************
		
		margins, dydx(`treat') at(`interact'=(0 1)) post
		est store bs_m`x'
		
		capture log close
		
		*Marginsplot
		marginsplot, 	recast(scatter) ///
			/*title*/ 	title("Impact of `label_treat' depending on `interact_treat'", size(medsmall) position(12)) subtitle("group: `vallabel`x''", position(12)) ///  (note: need to define labels to make sense)
			/*axes*/	xlabel(-0.4 " " 0 "`interact_vallabel0'" 1 "`interact_vallabel1'" 1.4 " ", notick) xtitle(" ") ytitle(" ") ylabel(-10(5)10)	///
			/*layout*/	scheme(s1mono) yline(0, lcolor(black))
		
		graph export "$graph\weighted_results_bs_`x'_`treat'_`interact'.png", replace
		
		}
	
	}
	
 }


 *this graph used in paper (figure 2):
 
coefplot (bs_m1, label(Wave 1)) (bs_m2, label(Wave 2)) (bs_m3, label(Wave 3)) (bs_m4, label(Wave 4)), vertical ///
	        /*axes*/	xlabel(0.6 " " 1 "No children under 15" 2 "At least one child under 15" 2.4 " ", notick) xtitle(" ") ytitle(" ") ylabel(-5(5)10)	///
			/*legend*/  legend(rows(1) size(small)) ///
			/*layout*/	scheme(s1mono) yline(0, lcolor(black)) 
			
			///
	*		/*notes*/   note("Source: IAB-HOPP, authors' calculations." "Only children under 15 considered." "Based on models in table 2.")
graph export "$graph\weighted_coeff_bs.png", replace

 
********************************************************************************			********************************************************************************
********************************************************************************			
			
					
			
***CHILDCARE SPECIFICATION:
*---------------------------

  forvalues x = 1/4 {
    
	foreach treat in female {
	    
		foreach interact in access_ftcc {
		
		**************
		*Define locals
		**************
		
		*Variable labels (treatment and interaction variable)
		local label_treat: 		variable label `treat'
		local interact_treat:	variable label `interact'
		
		*Value labels (sub-group variable)
		local groupvallabel: value label $sub 
		local vallabel`x': label `groupvallabel' `x'
		
		*Value labels (interaction variable)
		local interact_vallabel: value label `interact' 
		levelsof `interact', local(levels)
			foreach l of local levels {
			local interact_vallabel`l': label `interact_vallabel' `l'
			di as text "`interact_vallabel`l''"
			}
		
		***********
		*Regression
		************
		log using "$log/weighted_margins_cc`x'.log", replace
		
		reg diff`x' i.female##i.access_ftcc $general $fam $work $emphist [aweight=$weight], robust
		
		******************
		*Calculate margins
		*******************
		 
		margins, dydx(`treat') at(`interact'=(0 1 2)) post
		est store cc_m`x'

		capture log close
		
		*Marginsplot
		marginsplot, 	recast(scatter) ///
			/*title*/ 	title("Impact of `label_treat' depending on `interact_treat'", size(medsmall) position(12)) subtitle("group: `vallabel`x''", position(12)) ///  (note: need to define labels to make sense)
			/*axes*/	xlabel(-0.4 " " 0 "`interact_vallabel0'" 1 "`interact_vallabel1'" 2 "`interact_vallabel2'" 2.4 " ", notick) xtitle(" ") ytitle(" ") ylabel(-10(5)10)	///
			/*layout*/	scheme(s1mono) yline(0, lcolor(black))
		
		graph export "$graph\weighted_results_cc_`x'_`treat'_`interact'.png", replace
		
		}
	
	}
	
}
	
*figure 4 in paper:

coefplot (cc_m1, label(Wave 1)) (cc_m2, label(Wave 2)) (cc_m3, label(Wave 3)) (cc_m4, label(Wave 4)), vertical ///
	       	/*axes*/	xlabel(0.6 " " 1 "No children under 15" 2 "No/part-time childcare" 3 "Full-time childcare" 3.4 " ", notick)  ///
						xtitle(" ") ytitle(" ") ylabel(-5(5)10)	///
			/*legend*/  legend(rows(1) size(small)) ///
			/*layout*/	scheme(s1mono) yline(0, lcolor(black)) 
			
		*	/*notes*/   note("Source: IAB-HOPP, authors' calculations." "Only children under 15 considered." "Based on models in table 3.")
graph export "$graph\weighted_coeff_cc.png", replace

