***************************************
*GRAPHS - work hours over time
***************************************
***************************************
* work hous over time 
*
* Author: LT + VK
***************************************
set more off
set trace off

do $path\HOPPprepared\do\globals

*special global to save results as version 2:
gl results  $path\HOPPprepared\results\family_paper\version2
gl graph $path\HOPPprepared\graph\family_paper\version2

*--------------------------------------------------------------------------

//////////////////////////////////////////////////////////////////////////////
						***		weighted ONLY 	  ***
/////////////////////////////////////////////////////////////////////////////

	*here the 2 descriptive graphs on working hours get created. 
	
******************************************************
**** For parents vs. non-parents (also by gender)
******************************************************

use  $data\analysis_fam_panel_weights_KIDS_NEW.dta, clear
drop if par_2 ==1		

gl weight cweight_rlc



************************************
*** work hours over time
** (to be posted in results file)
************************************
for any hours time father mother non_mother non_father parent non_parent: cap drop X

***Generate subgroups and time variable
clonevar hours 	= workhours
clonevar time	= covidtime
la var hours	"working hours" 


*Define subgroups
gen fathers 	= female == 0 & dummykid == 1 //& (kid_small == 1 | kid_big == 1)
gen mothers 	= female == 1 & dummykid == 1 //& (kid_small == 1 | kid_big == 1)
gen non_mothers	= female == 1 & dummykid == 0
gen non_fathers	= female == 0 & dummykid == 0
gen parents     = dummykid == 1 //& (kid_small == 1 | kid_big == 1)
gen non_parents	= dummykid == 0
gen women 		= female == 1
gen men			= female == 0



***********************************
*Check means of subgroups manually
***********************************
bysort time: sum hours [aweight=$weight] if fathers     == 1
bysort time: sum hours [aweight=$weight] if non_fathers == 1

bysort time: sum hours [aweight=$weight] if mothers     == 1
bysort time: sum hours [aweight=$weight] if non_mothers == 1

bysort time: sum hours [aweight=$weight] if parents     == 1
bysort time: sum hours [aweight=$weight] if non_parents == 1

bysort time: sum hours [aweight=$weight] if women       == 1
bysort time: sum hours [aweight=$weight] if men		  == 1

*Define globals
global times 	"0 1 2 3 4" //more time points to be added depending on waves
global subs	 	"fathers non_fathers mothers non_mothers parents non_parents women men"
global outcomes "hours" //more outcomes to be added depending on questions/y of interest

*Open postfile //change storage path at end of command
postutil clear
postfile hours_uw str20 outcome time str20 group average using "$results\hours_uw.dta", replace


*Calculate means

foreach y in $outcomes {

	foreach sub in $subs {

		foreach t in $times {
		
		*Define locals
		local varlabel: variable label `y'
		
		*Calculate group-specific mean 
		sum `y' [aweight=$weight] if `sub' == 1 & time == `t'
		
		*Store results 
		scalar average = `r(mean)'
		
		*Post results
		post hours_uw ("`varlabel'") (`t') ("`sub'") (average)
		
		}
		
	}
	
}

postclose hours_uw


************************
**Load generated dataset
************************

use "$results\hours_uw.dta", clear


*Prepare dataset
encode 	group, gen(group_num)
encode  outcome, gen(outcome_id)

*Gen quasi-wide format
foreach sub in $subs {
	
gen average_`sub' = average if group == "`sub'"

}


*************************************
***Var labels
*************************************
la var average_father 		"Men with child(ren) under 15" 
la var average_mother 		"Women with child(ren) under 15"
la var average_non_mother 	"Women without children under 15"
la var average_non_father 	"Men without children under 15"
la var average_parent 		"Parents"
la var average_non_parent 	"Non-parents"
la var average_women 		"Women's average"
la var average_men 			"Men's average"


*************************************
***Graph command
*************************************

graph set window fontface "Times New Roman"


	
*** All in one graph

twoway 								///
(connected average_non_father  time, lpattern(dash) mcolor(black) msymbol(circle)) ///
(connected average_non_mother time, lpattern(dash) mcolor(gs10) lcolor(gs10) msymbol(circle)) ///
(connected  average_father time, lpattern(shortdash) lcolor(black) mcolor(black) msymbol(triangle))  ///
(connected average_mother  time, lpattern(shortdash) mcolor(gs10) lcolor(gs10) msymbol(triangle)) 		///
(connected average_men time,  lwidth(thick) lpattern(solid) lcolor(black) mcolor(black) msymbol(square))   ///
(connected average_women time, lwidth(thick) lpattern(solid) mcolor(gs10) lcolor(gs10) msymbol(square)) 	///
, xlabel(0.8 " " 0 "Before COVID-19" 1 "Wave 1" 2 "Wave 2" 3 "Wave 3" 4 "Wave 4" 2.2 " ", notick labsize(small))  ylabel(20(5)45) 	ytitle("Weekly working hours") xtitle(" ") ///
 /*note*/	note("" , size(small))	 ///
 legend(size(small) textwidth(39cm) forcesize symxsize(8pt)) 	///
scheme(s1mono) 

graph export "$graph\hours_development_all_weighted.png", as(png) replace


*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~
*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~
*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~
*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~



*******************************************************
**** Mothers / Fathers with/without childcare access
*******************************************************

use  $data\analysis_fam_panel_weights_KIDS_NEW.dta, clear
*ONLY PEOPLE WITH WEIGHTS THERE. NEED TO GET RID OF PEOPLE WITH UNCLEAR INFO ON CHILDREN:
drop if par_2 ==1		//27 ids dropped
*(DON'T NEED TO CHANGE kid_small/dummykid BELOW BECAUSE HAS THE SAME INFO AS par_1)

gl weight cweight_rlc


************************************
*** work hours over time
** (to be posted in results file)
************************************
for any hours time fathers_nocc fathers_ptcc fathers_ftcc mothers_nocc mothers_ptcc mothers_ftcc: cap drop X

***Generate subgroups and time variable
clonevar hours 	= workhours
clonevar time	= covidtime
la var hours	"working hours" 


*Define subgroups
gen fathers_noptcc 	= female == 0 & access_ftcc == 1 //& (kid_small == 1 | kid_big == 1)
gen fathers_ftcc 	= female == 0 & access_ftcc == 2 //& (kid_small == 1 | kid_big == 1)
gen mothers_noptcc 	= female == 1 & access_ftcc == 1 //& (kid_small == 1 | kid_big == 1)
gen mothers_ftcc 	= female == 1 & access_ftcc == 2 //& (kid_small == 1 | kid_big == 1)
gen non_mothers	    = female == 1 & access_ftcc == 0 
gen non_fathers	    = female == 0 & access_ftcc == 0 


*Define globals
global times 	"0 1 2 3 4" //more time points to be added depending on waves
global subs2 "fathers_noptcc fathers_ftcc non_fathers mothers_noptcc mothers_ftcc non_mothers"
global outcomes "hours" //more outcomes to be added depending on questions/y of interest

*Open postfile //change storage path at end of command
postutil clear
postfile hours_cc str20 outcome time str20 group average using "$results\hours_cc.dta", replace


*Calculate means new

foreach y in $outcomes {

	foreach sub in $subs2 {

		foreach t in $times {
		
		*Define locals
		local varlabel: variable label `y'
		
		*Calculate group-specific mean 
		sum `y' [aweight=$weight] if `sub' == 1 & time == `t'
		
		*Store results 
		scalar average = `r(mean)'
		
		*Post results
		post hours_cc ("`varlabel'") (`t') ("`sub'") (average)
		
		}
		
	}
	
}

postclose hours_cc


************************
**Load generated dataset
************************

use "$results\hours_cc.dta", clear


*Prepare dataset
encode 	group, gen(group_num)
encode  outcome, gen(outcome_id)

*Gen quasi-wide format
foreach sub in $subs2 {
	
gen average_`sub' = average if group == "`sub'"

}


*************************************
***Var labels
*************************************
la var average_non_fathers    "Men without children under 15"
la var average_fathers_noptcc "no/part-time childcare"
la var average_fathers_ftcc   "full-time childcare"

la var average_non_mothers    "Women without children under 15"
la var average_mothers_noptcc "no/part-time childcare"
la var average_mothers_ftcc   "full-time childcare"



*************************************
***Graph command
*************************************


*** All in one graph
twoway        		///	
(connected average_non_fathers time, lpattern(dash) mcolor(black) msymbol(circle)) ///
(connected average_non_mothers time, lpattern(dash) mcolor(gs10) lcolor(gs10) msymbol(circle)) ///
(connected average_fathers_noptcc time, lpattern(shortdash) lcolor(black) mcolor(black) msymbol(triangle))  ///
(connected average_mothers_noptcc time, lpattern(shortdash) mcolor(gs10) lcolor(gs10) msymbol(triangle)) 		///
(connected average_fathers_ftcc time,  lwidth(thick) lpattern(solid) lcolor(black) mcolor(black) msymbol(square))   ///
(connected average_mothers_ftcc time, lwidth(thick) lpattern(solid) mcolor(gs10) lcolor(gs10) msymbol(square)) ///
, 	xlabel(0.8 " " 0 "Before COVID-19" 1 "Wave 1" 2 "Wave 2" 3 "Wave 3" 4 "Wave 4" 2.2 " ", notick labsize(small))		///
 /*note*/ note("")			///
legend(size(small) textwidth(39cm) forcesize symxsize(8pt)  order(1 2 - "Men with child(ren) under 15:"  - "Women with child(ren) under 15:" 3 4 5 6) ) 	///
ytitle("Weekly working hours") xtitle(" ")	scheme(s1mono)

graph export "$graph\hours_development_all_cc_weighted.png", as(png) replace








